@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.2.1, released
- *  on Fri Jun 14 14:46:05 UTC 2019
+ *  This file is part of MUMPS 5.3.1, released
+ *  on Fri Apr 10 13:52:30 UTC 2020
  *
  *
- *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -28,7 +28,7 @@ extern "C" {
 
 #ifndef MUMPS_VERSION
 /* Protected in case headers of other arithmetics are included */
-#define MUMPS_VERSION "5.2.1"
+#define MUMPS_VERSION "5.3.1"
 #endif
 #ifndef MUMPS_VERSION_MAX_LEN
 #define MUMPS_VERSION_MAX_LEN 30
@@ -48,6 +48,7 @@ typedef struct {
     ZMUMPS_REAL    dkeep[230];
     MUMPS_INT8     keep8[150];
     MUMPS_INT      n;
+    MUMPS_INT      nblk;
 
     MUMPS_INT      nz_alloc; /* used in matlab interface to decide if we
                                 free + malloc when we have large variation */
@@ -72,6 +73,10 @@ typedef struct {
     MUMPS_INT      *eltvar;
     ZMUMPS_COMPLEX *a_elt;
 
+    /* Matrix by blocks */
+    MUMPS_INT      *blkptr;
+    MUMPS_INT      *blkvar;
+
     /* Ordering, if given by user */
     MUMPS_INT      *perm_in;
 
