@@ -1,15 +1,19 @@
 !
-!  This file is part of MUMPS 5.1.2, released
-!  on Mon Oct  2 07:37:01 UTC 2017
+!  This file is part of MUMPS 5.3.1, released
+!  on Fri Apr 10 13:52:30 UTC 2020
 !
 !
-!  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
-!  University of Bordeaux.
+!  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+!  Mumps Technologies, University of Bordeaux.
 !
 !  This version of MUMPS is provided to you free of charge. It is
 !  released under the CeCILL-C license:
 !  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
 !
+!     This file includes various internal datastructures
+!     passed through the main MUMPS structure between successive
+!     phases of the solver. The main one is root information for
+!     the multifrontal tree.
       TYPE ZMUMPS_ROOT_STRUC
         SEQUENCE
         INTEGER :: MBLOCK, NBLOCK, NPROW, NPCOL
@@ -43,3 +47,9 @@
         INTEGER :: NB_SINGULAR_VALUES,rootpad4
 !
       END TYPE ZMUMPS_ROOT_STRUC
+!     multicore
+      TYPE ZMUMPS_L0OMPFAC_T
+         SEQUENCE
+         COMPLEX(kind=8), POINTER, DIMENSION(:) :: A
+         INTEGER(8) :: LA
+      END TYPE ZMUMPS_L0OMPFAC_T
