@@ -1,10 +1,10 @@
 /*
  *
- *  This file is part of MUMPS 5.2.1, released
- *  on Fri Jun 14 14:46:05 UTC 2019
+ *  This file is part of MUMPS 5.3.1, released
+ *  on Fri Apr 10 13:52:30 UTC 2020
  *
  *
- *  Copyright 1991-2019 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
@@ -42,11 +42,9 @@
 extern "C" {
 #endif
 
-/* This is the minimum to have the C interface of MUMPS work.
- * Most of the time, users who need this file have no call to MPI functions in
- * their own code. Hence it is not worth declaring all MPI functions here.
- * However if some users come to request some more stub functions of the MPI
- * standards, we may add them. But it is not worth doing it until then. */
+/* This is the minimum to have the C interface to MUMPS work with the
+ * C example provided. Other stub functions of the MPI standard may be
+ * added if needed. */
 
 typedef LIBSEQ_INT MPI_Comm; /* Simple type for MPI communicator */
 static MPI_Comm MPI_COMM_WORLD=(MPI_Comm)0;
@@ -55,6 +53,12 @@ LIBSEQ_INT LIBSEQ_CALL MPI_Init(LIBSEQ_INT *pargc, char ***pargv);
 LIBSEQ_INT LIBSEQ_CALL MPI_Comm_rank(LIBSEQ_INT  comm, LIBSEQ_INT  *rank);
 LIBSEQ_INT LIBSEQ_CALL MPI_Finalize(void);
 
+/* For MPI_IS_IN_PLACE tests */
+void LIBSEQ_CALL MUMPS_CHECKADDREQUAL(char *a, char*b, LIBSEQ_INT *i);
+void LIBSEQ_CALL MUMPS_CHECKADDREQUAL_(char *a, char*b, LIBSEQ_INT *i);
+void LIBSEQ_CALL mumps_checkaddrequal_(char *a, char*b, LIBSEQ_INT *i);
+void LIBSEQ_CALL mumps_checkaddrequal__(char *a, char*b, LIBSEQ_INT *i);
+
 #ifdef __cplusplus
 }
 #endif
