@@ -1,11 +1,11 @@
 /*
  *
- *  This file is part of MUMPS 5.1.2, released
- *  on Mon Oct  2 07:37:01 UTC 2017
+ *  This file is part of MUMPS 5.3.1, released
+ *  on Fri Apr 10 13:52:30 UTC 2020
  *
  *
- *  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
- *  University of Bordeaux.
+ *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
  *  released under the CeCILL-C license:
@@ -34,5 +34,11 @@ void MUMPS_CALL
 MUMPS_METIS_KWAY(MUMPS_INT *n,     MUMPS_INT *iptr,
                  MUMPS_INT *jcn,   MUMPS_INT *k,
                  MUMPS_INT *part);
+#define MUMPS_METIS_KWAY_AB \
+  F_SYMBOL(metis_kway_ab,METIS_KWAY_AB)
+void MUMPS_CALL
+MUMPS_METIS_KWAY_AB(MUMPS_INT *n,     MUMPS_INT *iptr,
+                 MUMPS_INT *jcn,   MUMPS_INT *k,
+                 MUMPS_INT *part,  MUMPS_INT *vwgt);
 #endif
 #endif
