@@ -1,11 +1,11 @@
 /*
  *
- *  This file is part of MUMPS 5.1.2, released
- *  on Mon Oct  2 07:37:01 UTC 2017
+ *  This file is part of MUMPS 5.3.1, released
+ *  on Fri Apr 10 13:52:30 UTC 2020
  *
  *
- *  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
- *  University of Bordeaux.
+ *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
  *  released under the CeCILL-C license:
@@ -39,5 +39,11 @@ void MUMPS_CALL
 MUMPS_METIS_KWAY_64(MUMPS_INT8 *n,     MUMPS_INT8 *iptr,
                  MUMPS_INT8 *jcn,   MUMPS_INT8 *k,
                  MUMPS_INT8 *part);
+#define MUMPS_METIS_KWAY_AB_64 \
+  F_SYMBOL(metis_kway_ab_64,METIS_KWAY_AB_64)
+void MUMPS_CALL
+MUMPS_METIS_KWAY_AB_64(MUMPS_INT8 *n,     MUMPS_INT8 *iptr,
+                 MUMPS_INT8 *jcn,   MUMPS_INT8 *k,
+                 MUMPS_INT8 *part,  MUMPS_INT8 *vwgt);
 #endif
 #endif
