@@ -1,10 +1,10 @@
 C
-C  This file is part of MUMPS 5.1.2, released
-C  on Mon Oct  2 07:37:01 UTC 2017
+C  This file is part of MUMPS 5.3.1, released
+C  on Fri Apr 10 13:52:30 UTC 2020
 C
 C
-C  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
-C  University of Bordeaux.
+C  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+C  Mumps Technologies, University of Bordeaux.
 C
 C  This version of MUMPS is provided to you free of charge. It is
 C  released under the CeCILL-C license:
@@ -15,6 +15,24 @@ C  This file contains the definition
 C  of all tags.
 C -----------------------------------------
 C
+C ---------------
+C  Tags for L0OMP 
+C ---------------
+      INTEGER F_IPOOLAFTER, F_PHYS_L0
+      PARAMETER ( F_IPOOLAFTER = 60, F_PHYS_L0 = 61 )
+C -----------------
+C  Tag for grouping
+C -----------------
+      INTEGER GROUPING
+      PARAMETER ( GROUPING = 49 )
+C ----------------------------------------------
+C  Tag for LMAT distribution (analysis by block)
+C      and for gathering graph
+C ----------------------------------------------
+      INTEGER LMATDIST, GATHERG_NZG, GATHERG_NB, 
+     &        GATHERG_FIRST, GATHERG_IPE, GATHERG_ADJ
+      PARAMETER ( LMATDIST = 43, GATHERG_NZG=44, GATHERG_NB=45,
+     &        GATHERG_FIRST=46, GATHERG_IPE=47, GATHERG_ADJ= 48)
 C -----------------------------------------
 C  Tag for arrowheads distribution
 C -----------------------------------------
@@ -76,20 +94,26 @@ C -----------------------------------------
      &        Master2Slave,
      &        GatherSol,
      &        ScatterRhsI,
-     &        ScatterRhsR
+     &        ScatterRhsR,
+     &        DistRhsI,
+     &        DistRhsR
       PARAMETER( RACINE_SOLVE = 14,
      &           ContVec      = 11,
      &           Master2Slave = 12,
      &           GatherSol    = 13,
      &           ScatterRhsI  = 54,
-     &           ScatterRhsR  = 55)
+     &           ScatterRhsR  = 55,
+     &           DistRhsI     = 51,
+     &           DistRhsR     = 52)
+      INTEGER, PARAMETER :: DIST_RHS_INT    = 56
+      INTEGER, PARAMETER :: DIST_RHS_SCALAR = 57
 C -----------------------------------------
 C   Tags for backsolve
 C -----------------------------------------
-      INTEGER FEUILLE,
+      INTEGER TERMBWD,
      &        BACKSLV_UPDATERHS,
      &        BACKSLV_MASTER2SLAVE
-      PARAMETER( FEUILLE = 21,
+      PARAMETER( TERMBWD = 21,
      &           BACKSLV_UPDATERHS = 22,
      &           BACKSLV_MASTER2SLAVE = 23 )
 C ------------------------
